{
  Crystal Design Component demo application 1:

  Copyright (c) 1997, SupraSoft Ltd

  Purpose of this program is to demonstrate
  - Basic report activation and de-activation (Button1Click)
  - Page navigation (SpeedButton1/SpeedButton2Click)
  - Event handling for error status (CrystalDesign1Error)
  - Event handling for "please wait" kind of feature with hourglass cursor
    (CrystalDesign1JobStarted, CrystalDesign1JobCompleted)
  - "Current page / Last Page" label showing (CrystalDesign1JobCompleted)
  - Zoom in/out report (ScrollBar1Change)
  - "Print setup" feature (Button2Click)
  - "Print a report" feature (Button3Click)
}
unit Demo1;

interface

uses
  SysUtils, Messages, Classes, Controls,
  Forms, StdCtrls, Buttons, ExtCtrls,
  { Make sure that the directory of Crystal Design Component }
  { DCU-files is mentioned in a library path statement.      }
  Crystdsg, CrysPrnt;

type
  TForm1 = class(TForm)
    CrystalDesign1: TCrystalDesign;
    Panel1: TPanel;
    SpeedButton1: TSpeedButton;
    SpeedButton2: TSpeedButton;
    Button1: TButton;
    ScrollBar1: TScrollBar;
    Label1: TLabel;
    Label2: TLabel;
    Button3: TButton;
    Button2: TButton;
    procedure Button1Click(Sender: TObject);
    procedure SpeedButton1Click(Sender: TObject);
    procedure SpeedButton2Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure CrystalDesign1Error(Sender: TObject);
    procedure CrystalDesign1JobCompleted(Sender: TObject);
    procedure ScrollBar1Change(Sender: TObject);
    procedure CrystalDesign1AfterActive(Sender: TObject);
    procedure CrystalDesign1JobStarted(Sender: TObject);
    procedure Button3Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

procedure TForm1.FormCreate(Sender: TObject);
var
  exePath: string;
begin
  exePath := ExtractFilePath(Application.ExeName);

  { Report file AND database file are in the same place }
  { with the exectuable file.                           }
  CrystalDesign1.ReportLocation := exePath;
  CrystalDesign1.CommonTableLocations := exePath;
end;


procedure TForm1.Button1Click(Sender: TObject);
begin
  { Activate / Deactivate the report }
  CrystalDesign1.Active := not CrystalDesign1.Active;
end;

procedure TForm1.SpeedButton1Click(Sender: TObject);
begin
  { Goto the previous page }
  CrystalDesign1.ShowPrevPage;
end;

procedure TForm1.SpeedButton2Click(Sender: TObject);
begin
  { Goto the next page }
  CrystalDesign1.ShowNextPage;
end;

procedure TForm1.CrystalDesign1Error(Sender: TObject);
begin
  { Show the last error text in a caption }
  Label2.Caption := CrystalDesign1.LastErrorText;
end;

procedure TForm1.CrystalDesign1JobStarted(Sender: TObject);
begin
  { When a job is started, show a hourglass cursor }
  Screen.Cursor := crHourglass;
end;


procedure TForm1.CrystalDesign1JobCompleted(Sender: TObject);
begin
  { When job is completed, it's time to show a normal cursor }
  Screen.Cursor := crDefault;

  { This event is called when a report job is completed.               }
  { The job can be page navigation, report activation, printing,       }
  { drill down operaton etc.. This is a good place to update,          }
  { for example, page numbering labels or clear "please wait" status.  }

  { Show a page numbering in the panel. If the report is not yet fully }
  { processed (ie. total number of pages is inaccurate) then add       }
  { '+' char to end of the page numbering string.                      }
  Panel1.Caption := IntToStr(CrystalDesign1.ReportDisplayPage) + ' / ' +
                    IntToStr(CrystalDesign1.ReportLastPage);

  if CrystalDesign1.ReportPrintEnded = FALSE then
     Panel1.Caption := Panel1.Caption + '+';
end;

procedure TForm1.ScrollBar1Change(Sender: TObject);
begin
  { Change a zoom factor based on scrollbar position }
  CrystalDesign1.ZoomFactor := ScrollBar1.Position;
end;

procedure TForm1.CrystalDesign1AfterActive(Sender: TObject);
begin
  { If report was de-activated then clear page numbering text }
  if CrystalDesign1.Active = FALSE then Panel1.Caption := '';
end;

procedure TForm1.Button2Click(Sender: TObject);
begin
  { Show a print setup dialogbox using a method in CRYSPRNT unit.   }
  { Please note that these changes will take effect when you next   }
  { time activate (or refresh) the report or print it to a printer. }
  ShowReportPrintSetupDialog(CrystalDesign1);
end;

procedure TForm1.Button3Click(Sender: TObject);
begin
  { Show a standard print dialogbox using a method in CRYSPRNT unit }
  ShowReportPrintDialog(CrystalDesign1);
end;


end.
